@@ -42,6 +42,14 @@ def detect_scheduling_sys():
     except:
         pass
 
+
+    # Test for PBS
+    try:
+        line = check_output(['pbsnodes', '-a'])
+        return my_import('mycluster.pbs')
+    except:
+        pass
+
     # Test for SGE
     if os.getenv('SGE_CLUSTER_NAME') is not None:
         return my_import('mycluster.sge')
@@ -261,9 +269,14 @@ def print_queue_info():
                                      'Node Max Thread', 'Node Max Memory',
                                      'Max Task', 'Available Task'))
     for q in queues():
-        nc = scheduler.node_config(q)
-        tpn = scheduler.tasks_per_node(q)
-        avail = scheduler.available_tasks(q)
+        try:
+            nc = scheduler.node_config(q)
+            tpn = scheduler.tasks_per_node(q)
+            avail = scheduler.available_tasks(q)
+        except:
+            nc = None
+            tpn = None
+            avail = None
         print('{0:25} | {1:^15} | {2:^15} |\
                {3:^15} | {4:^15} | {5:^15}'.format(q, tpn,
                                                    nc['max thread'],
@@ -297,7 +310,7 @@ def create_submit(queue_id, script_name=None, **kwargs):
         return None
 
 
-def submit(script_name, immediate):
+def submit(script_name, immediate, depends=None):
 
     if scheduler is None:
         return None
@@ -305,7 +318,7 @@ def submit(script_name, immediate):
     job_id = -1
     import os.path
     if os.path.isfile(script_name):
-        job_id = scheduler.submit(script_name, immediate)
+        job_id = scheduler.submit(script_name, immediate, depends)
         if job_id is not None:
             print('Job submitted with ID {0}'.format(job_id))
         if job_db is not None and job_id is not None:
@@ -406,19 +419,22 @@ def create_db():
 
 
 def update_db():
-    if scheduler is not None:
-        status_dict = scheduler.status()
-        jobs = job_list()
-        for j in jobs:
-            if jobs[j].status != 'completed':
-                job_id = jobs[j].job_id
-                if job_id in status_dict:
-                    state = status_dict[job_id]
-                    if state == 'r':
-                        jobs[j].update_status('running')
-                else:
-                    jobs[j].update_status('completed')
-                    jobs[j].update_stats(scheduler.job_stats(job_id))
+    try:
+        if scheduler is not None:
+            status_dict = scheduler.status()
+            jobs = job_list()
+            for j in jobs:
+                if jobs[j].status != 'completed':
+                    job_id = jobs[j].job_id
+                    if job_id in status_dict:
+                        state = status_dict[job_id]
+                        if state == 'r':
+                            jobs[j].update_status('running')
+                    else:
+                        jobs[j].update_status('completed')
+                        jobs[j].update_stats(scheduler.job_stats(job_id))
+    except Exception as e:
+        print('Database failed to update. Error Message: ' + str(e))
 
 
 def sysscribe_update(job_id):
